HEADER = ("Clacks", "GNU Terry Pratchett")


class GNUTerryPratchett(object):
    def __init__(self, app):
        self.app = app

    def __call__(self, environ, start_response):
        def clacker(status, headers, *args, **kwargs):
            if HEADER not in headers:
                headers.append(HEADER)
            return start_response(status, headers, *args, **kwargs)

        return self.app(environ, clacker)



import sys
if sys.argv[1] == 'develop':
    from setuptools import setup
else:
    from distutils.core import setup

setup(
    name='wsgi-pratchett',
    version='1.0.0',
    author='Travis Swicegood',
    author_email='development@domain51.com',
    description='GNU Terry Pratchett for WSGI',
    long_description=open("./README.rst").read(),
    packages=['pratchett', ],
    include_package_data=True,
    zip_safe=False,
)
